/* Application Explorer - a general-purpose application cataloger/indexer
 * Copyright (C) 2006  Aliasgar Lokhandwala <d7@freepgs.com> 
 * http://appexp.sourceforge.net/
 *
 * ListedFile.java: the class for representing files that are listed 
 * 	(in the right side pane)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package app.appexplorer.file;

import java.io.File;
import java.util.logging.LogManager;
import java.util.logging.Logger;

/**
 * Allows File objects to be added to the right-side pane. A ListedFile is a
 * file listed in the right-side pane. The key reason for this class is to
 * override the toString() method to return the file name. This allows the
 * objects to be added directly to the right-side pane.
 * 
 * @version 2.0
 * @author ali
 */
public final class ListedFile {

    /**
     * The file object attached to this class.
     */
    private File m_file;

    /**
     * The logger used to log any messages.
     */
    private static Logger m_globalLogger = LogManager.getLogManager()
            .getLogger("global");

    /**
     * Create a ListedFile and attach it with the supplied file object.
     * 
     * @param file -
     *            a File object. Should not be null.
     */
    public ListedFile(File file) {
        m_file = file;
    }

    /**
     * Return the name of this file as the string representation of this object.
     * This allows us to send a vector of ListedFile objects directly to a
     * JList.
     * 
     * @see javax.swing.JList#JList(java.util.Vector)
     */
    public String toString() {
        return m_file.getName();
    }

    /**
     * Returns the absolute path to this file. The returned string is an
     * abstract path.
     * 
     * @return The absolute path of this file.
     */
    public String getPath() {
        return m_file.getAbsolutePath();
    }
}